#!/usr/bin/env python3
# Display Latin famous phrases in the terminal - python version
# Armaan Bhojwani 2020

import argparse
from random import randint
import sqlite3
import sys
import os.path

def main(args=sys.argv[1:]):
    # Argument parsing
    parser = argparse.ArgumentParser(
        description="Latin famous phrases in the terminal.")
    parser.add_argument("-i", "--id",
                        action='store_true',
                        help="print the id of the phrase.")
    parser.add_argument("-l", "--latin",
                        action='store_true',
                        help="print the Latin phrase (default)")
    parser.add_argument("-e", "--english",
                        action='store_true',
                        help="print the English translation.")
    parser.add_argument("-n", "--notes",
                        action='store_true',
                        help="print any notes on phrase.")
    parser.add_argument("-m", "--min",
                        default=0,
                        type=int,
                        help="set the minimum length of the Latin phrase.")
    parser.add_argument("-M", "--max",
                        default=10000000,
                        type=int,
                        help="set the maximum length of Latin phrase.")
    parser.add_argument("-p", "--num",
                        action='store_true',
                        help="print number of possible phrases.")
    parser.add_argument("-f", "--file",
                        help="set the location of the phrase database.")
    parser.add_argument("-o", "--open",
                        type=int,
                        help="specify the id of a specific phrase to print.")
    args = parser.parse_args()

    # find phrase file
    if args.file:
        phrase_file = args.file
    if os.path.isfile("phrases.db"):
        phrase_file = "phrases.db"
    elif os.path.isfile("/usr/local/share/phrases/phrases.db"):
        phrase_file = "/usr/local/share/phrases/phrases.db"
    else:
        sys.exit("cannot find the phrase database!")
    
    conn = sqlite3.connect(phrase_file)
    c = conn.cursor()
    c.execute("SELECT * FROM phrases WHERE length <= (?) AND length >= (?)",
              (args.max, args.min))
    data = c.fetchall()
    rown = randint(0, len(data))
    row = list(data[rown]) 

    # Output as specified in flags
    if not (args.id
            or args.latin
            or args.english
            or args.notes
            or args.num):
        print(row[1])
        sys.exit(0)
    else:
        if args.id:
            print(row[0])
        if args.latin:
            print(row[1])
        if args.english:
            print(row[2])
        if args.notes:
            print(row[3])
        if args.num:
            print(len(data))
        sys.exit(0)

if __name__ == "__main__":
    main()
